@@ -18,11 +18,11 @@ TAP::Parser::Multiplexer - Multiplex multiple TAP::Parsers
 
 =head1 VERSION
 
-Version 3.45_01
+Version 3.45_02
 
 =cut
 
-our $VERSION = '3.45_01';
+our $VERSION = '3.45_02';
 
 =head1 SYNOPSIS
 
@@ -134,7 +134,7 @@ sub _iter {
         until (@ready) {
             return unless $sel->count;
             @ready = $sel->can_read;
-            last if @ready || $! != Errno::EINTR;
+            last if @ready || $!{EINTR};
         }
 
         my ( $h, $parser, $stash, @handles ) = @{ shift @ready };
